--	LibScriptLink
--	Implements a hyperlink scripting system that (hopefully) avoids taint.


local major, minor, addonTable = LibStub("LibBuilder-1.0"):GetLib()
if not addonTable.canLoad then return end


local LibScriptLink = addonTable.interface

local libPrint = LibStub("LibPrint-1.0")
LibScriptLink.debugStream = libPrint:NewStream("LibScriptLink", "mcm")


function LibScriptLink:Debug(...)
	self.debugStream:Print(...)
end


function LibScriptLink:MakeLink(label, callback, color)
	local linkBuilder = addonTable.classes.LinkBuilder:New()
	
	linkBuilder:SetLabel(label)
	linkBuilder:SetCallback(callback)
	
	if color then
		linkBuilder:SetColor(color)
	end
	
	return linkBuilder:Build()
end


function LibScriptLink:NewLinkBuilder()
	return addonTable.classes.LinkBuilder:New()
end


function LibScriptLink:HookAll()
	addonTable.classes.Core:HookAll()
end


function LibScriptLink:UnhookAll()
	addonTable.classes.Core:UnhookAll()
end


function LibScriptLink:Test()
	local link0, link1, link2
	local func0, func1, func2
	
	func0 = function()
		DEFAULT_CHAT_FRAME:AddMessage(strjoin(" ", link1, link2))
	end
	
	func1 = function()
		print("test1")
	end
	
	func2 = function()
		print("test2")
	end
	
	link0 = self:MakeLink("[Click Here]", func0)
	link1 = self:MakeLink("[Test Link 1]", func1)
	link2 = self:MakeLink("[Test Link 2]", func2)

	self:Debug(link0, "to print test links to the default chat frame.")
end


LibScriptLink:HookAll()

