--	LinkBuilder
--	Bundles functions used to prepare a scriptlink.


local major, minor, addonTable = LibStub("LibBuilder-1.0"):GetLib()
if not addonTable.canLoad then return end


local LinkBuilder, linkBuilder = addonTable:NewClass("LinkBuilder")


function LinkBuilder:New()
	local instance = {}
	setmetatable(instance, self.instanceMetatable)
	return instance
end


function linkBuilder:SetLabel(label)
	self.label = label
end

function linkBuilder:GetLabel()
	return self.label or ""
end

function linkBuilder:SetCallback(callback)
	local argType = type(callback)
	
	if argType == "function" then
		self.callback = callback
	elseif argType == "string" then
		local func, message = loadstring(callback)
		
		if not func then
			error("Could not compile callback")
		end
		
		self.callback = func
	else
		error("Invalid callback type")
	end
end


function linkBuilder:GetCallback()
	return self.callback
end

function linkBuilder:SetColor(color)
	--	FIXME: check format
	self.color = color
end


function linkBuilder:GetColor()
	return self.color or "ffcccc00"	--	TODO: pick a default color
end


--	NOTE: creates a different reference each time it's called
function linkBuilder:Build()
	local reference = addonTable.classes.Core:RegisterCallback(self:GetCallback())
	
	local color = self:GetColor()
	local label = self:GetLabel()

	local scriptLink = string.format("|c%s|HScriptLink:ref:%s|h%s|h|r", color, reference, label)

	return scriptLink
end
